### R code from vignette source 'mcprofile.Rnw'
### Encoding: ISO8859-1

###################################################
### code chunk number 1: loadpackage
###################################################
library(mcprofile)


###################################################
### code chunk number 2: ctadata
###################################################
data(cta)
str(cta)
cta$concf <- factor(cta$conc, levels=unique(cta$conc))

ggplot(cta, aes(y=foci, x=concf)) + 
   geom_boxplot() +
   geom_dotplot(binaxis = "y", stackdir = "center", binwidth = 0.2) +    
   xlab("concentration")


###################################################
### code chunk number 3: ctam1
###################################################
(m1 <- glm(foci ~ concf, data=cta, family=poisson(link="log")))
# confidence intervals for beta_j
confint(m1, parm=2:8)


###################################################
### code chunk number 4: m1profile
###################################################
cm1 <- cbind(0, diag(7))
rownames(cm1) <- paste(levels(cta$concf)[-1], levels(cta$concf)[1], sep=" - ")
print(cm1)

p1 <- mcprofile(m1, cm1)
confint(p1, adjust="none")


###################################################
### code chunk number 5: ctam2
###################################################
(m2 <- glm(foci ~ concf-1, data=cta, family=poisson(link="log")))

# m1 and m2 are the same models with different parameterization
all.equal(deviance(m1), deviance(m2))


###################################################
### code chunk number 6: m2profile
###################################################
library(multcomp)
(cm2 <- contrMat(table(cta$concf), type="Dunnett"))

p2 <- mcprofile(m2, cm2)
(ci <- confint(p2, adjust="none"))


###################################################
### code chunk number 7: plot1
###################################################
plot(p2) + ylim(c(-5,5))


###################################################
### code chunk number 8: plot2
###################################################
plot(ci)


###################################################
### code chunk number 9: plot3
###################################################
plot(exp(ci)) + 
  coord_trans(x="log") +
  geom_vline(xintercept=1, lty=2)


###################################################
### code chunk number 10: grid
###################################################
cgrid <- sapply(1:nrow(cm2), function(i) seq(-3, 5, length=25))
head(cgrid)

p3 <- mcprofile(m2, cm2, grid=cgrid)
plot(p3) 


###################################################
### code chunk number 11: ci1
###################################################
(ci2 <- confint(p2, adjust="single-step"))


###################################################
### code chunk number 12: test1
###################################################
summary(p2, margin=1, alternative="greater")


###################################################
### code chunk number 13: wald
###################################################
w2 <- wald(p2)
plot(w2) + ylim(c(-5,5))


###################################################
### code chunk number 14: multcomp
###################################################
confint(glht(m2, cm2))
confint(w2)


###################################################
### code chunk number 15: hoa
###################################################
h2 <- hoa(p2)
confint(h2)


###################################################
### code chunk number 16: toxin
###################################################
data(toxinLD)
toxinLD$logdose <- log(toxinLD$dose)
ggplot(toxinLD, aes(x=logdose, y=dead/(dead+alive))) + 
  geom_point(size=3)


###################################################
### code chunk number 17: logisticregression
###################################################
mlr <- glm(cbind(dead, alive) ~ logdose, data=toxinLD, family=binomial(link="logit"))


###################################################
### code chunk number 18: lrcm
###################################################
pdose <- seq(-1,2.3, length=20)
cmlr <- model.matrix(~ pdose)
rownames(cmlr) <- round(pdose, 2)
head(cmlr)

plr <- mcprofile(mlr, cmlr)
cilr <- confint(plr)

plot(cilr) +
  xlab("logit(mu)") +
  ylab("log dose level")


###################################################
### code chunk number 19: lrciplot
###################################################
pdat <- data.frame(logdose=pdose)
pdat$estimate <- mlr$family$linkinv(cilr$estimate$Estimate)
pdat$lower <- mlr$family$linkinv(cilr$confint$lower)
pdat$upper <- mlr$family$linkinv(cilr$confint$upper)

ggplot(toxinLD, aes(x=logdose, y=dead/(dead+alive))) + 
  geom_ribbon(data=pdat, aes(y=estimate, ymin=lower, ymax=upper), size=0.95, fill="lightblue") +
  geom_line(data=pdat, aes(y=estimate), size=0.95) +
  geom_point(size=3) +
  ylab("Mortality rate")


